darkhistory.spec.spectools.get_normalized_spec — DarkHistory documentation

# darkhistory.spec.spectools.get_normalized_spec

`darkhistory.spec.spectools.` `get_normalized_spec`(spec, dE_dVdt, rs)

  Normalizes the spectrum to per baryon per dlnz, given dE/(dV dt).

  Parameters: | spec : Spectrum Input spectrum to be normalized. dE_dVdt : float The injection dE/(dV dt) in eV cm^-3 s^-1. rs : float The redshift (1+z).
  Returns: | Spectrum The normalized spectrum (per baryon per dlnz).

#### Previous topic

darkhistory.spec.spectools.get_log_bin_width

#### Next topic

darkhistory.spec.spectools.rebin_N_arr

### This Page

Show Source